/*
 * Segment Datenübernahme und Aufbereitung (DUA), SWE Messwertersetzung LVE
 * Copyright (C) 2007 BitCtrl Systems GmbH
 * Copyright 2016 by Kappich Systemberatung Aachen
 *
 * This file is part of de.bsvrz.dua.mwelve.
 *
 * de.bsvrz.dua.mwelve is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.dua.mwelve is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.dua.mwelve.  If not, see <http://www.gnu.org/licenses/>.

 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */

package de.bsvrz.dua.mwelve.pllovlve;

import de.bsvrz.dua.mwelve.vew.VerwaltungMessWertErsetzungLVE;
import de.bsvrz.sys.funclib.bitctrl.dua.DUAInitialisierungsException;
import de.bsvrz.sys.funclib.bitctrl.dua.DUAKonstanten;
import de.bsvrz.sys.funclib.bitctrl.dua.StandardAspekteVersorger;

/**
 * Diese Klasse repräsentiert die Versorgung des Moduls Pl-Prüfung logisch LVE
 * (innerhalb der SWE Messwertersetzung LVE) mit
 * Standard-Publikationsinformationen (Zuordnung von
 * Objekt-Datenbeschreibung-Kombination zu Standard- Publikationsaspekt).
 *
 * @author BitCtrl Systems GmbH, Thierfelder
 */
public class PlLogMweLveStandardAspekteVersorger extends StandardAspekteVersorger {

	/**
	 * Standardkonstruktor.
	 *
	 * @param verwaltung Verbindung zum Verwaltungsmodul
	 * @throws DUAInitialisierungsException wird weitergereicht
	 */
	public PlLogMweLveStandardAspekteVersorger(VerwaltungMessWertErsetzungLVE verwaltung)
			throws DUAInitialisierungsException {
		super(verwaltung);
	}

	@Override
	protected void init() throws DUAInitialisierungsException {

		if (((VerwaltungMessWertErsetzungLVE) verwaltung).isVerarbeiteLangzeitdaten()) {
			this.standardAspekte = new StandardAspekteAdapter(new StandardPublikationsZuordnung[] {
					new StandardPublikationsZuordnung(DUAKonstanten.TYP_FAHRSTREIFEN, DUAKonstanten.ATG_KZD,
							DUAKonstanten.ASP_EXTERNE_ERFASSUNG, DUAKonstanten.ASP_PL_PRUEFUNG_LOGISCH),
					new StandardPublikationsZuordnung(DUAKonstanten.TYP_FAHRSTREIFEN, DUAKonstanten.ATG_LZD,
							DUAKonstanten.ASP_EXTERNE_ERFASSUNG, DUAKonstanten.ASP_PL_PRUEFUNG_LOGISCH) });
		} else {
			this.standardAspekte = new StandardAspekteAdapter(new StandardPublikationsZuordnung[] {
					new StandardPublikationsZuordnung(DUAKonstanten.TYP_FAHRSTREIFEN, DUAKonstanten.ATG_KZD,
							DUAKonstanten.ASP_EXTERNE_ERFASSUNG, DUAKonstanten.ASP_PL_PRUEFUNG_LOGISCH) });
		}
	}
}
